@@ -240,8 +240,13 @@ class CameraModelForm(ModelForm):
                 'tripod',
                 'self_timer',
                 'date_imprint',
-                'power_drive',
+                'interchangeable_backs',
+                'interchangeable_finders',
+                'strap_lugs',
+                'multiple_exposures',
+                'internal_power_drive',
                 AppendedText('continuous_fps', 'fps'),
+                'external_power_drive',
             ),
             Fieldset(
                 'Misc',
